<?php

namespace Drupal\private_media\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Class ProcessBatchForm.
 */
class ProcessBatchForm extends FormBase {

  /**
   * Drupal\Core\Database\Driver\mysql\Connection definition.
   *
   * @var \Drupal\Core\Database\Driver\mysql\Connection
   */
  protected $database;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    $instance = parent::create($container);
    $instance->database = $container->get('database');
    return $instance;
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'process_batch_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    return [
      'file_operation' => [
        '#type' => 'select',
        '#title' => $this->t('Move Qualifying Media to:'),
        '#options' => [
          'private' => 'Private',
          'public' => 'Public',
        ],
      ],
      'submit' => [
        '#type' => 'submit',
        '#value' => $this->t('Go!'),
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $op = $form_state->getValue('file_operation');
    if (!empty($op)) {
      $mids = $this->database->select('media')->fields('media', ['mid'])->execute()->fetchCol();
      $batch = [
        'title' => $this->t('Moving Qualifying Media'),
        'operations' => array_map(function ($mid) use ($op) {
          return ['private_media_batch_update', [$mid, $op]];
        }, $mids),
      ];

      batch_set($batch);
    }
  }

}
